@@ -19,12 +19,15 @@ class IdentityKey(models.Model):
     """
     A user has one IdentityKey created at registration time
     """
+    keyId = models.IntegerField()
     public = models.CharField(max_length=44)
-    deviceId = models.IntegerField(default=0)
     localId = models.IntegerField()
     user = models.OneToOneField(User, on_delete=models.CASCADE, related_name='identityKey')
     cipher = models.CharField(max_length=88)
     salt = models.CharField(max_length=44)
+    active = models.BooleanField(default=False)
+    timestamp = models.CharField(max_length=100)
+    dt_timestamp = models.DateTimeField(auto_now_add=True)
 
 
 class SignedPreKey(models.Model):
@@ -38,8 +41,8 @@ class SignedPreKey(models.Model):
     cipher = models.CharField(max_length=88)
     salt = models.CharField(max_length=44)
     active = models.BooleanField(default=False)
-    timestamp = models.DateTimeField(auto_now_add=True)
-    unixTimestamp = models.CharField(max_length=100)
+    timestamp = models.CharField(max_length=100)
+    dt_timestamp = models.DateTimeField(auto_now_add=True)
 
     class Meta:
         constraints = [models.UniqueConstraint(fields=['keyId', 'user'], name='unique_signed_prekey')]
@@ -47,7 +50,7 @@ class SignedPreKey(models.Model):
 
 class PreKey(models.Model):
     """
-    A user has a bunch of PreKeys created at registration time
+    A user has a list of PreKeys created at registration time
     """
     keyId = models.IntegerField()
     public = models.CharField(max_length=44)
@@ -55,6 +58,7 @@ class PreKey(models.Model):
     used = models.BooleanField(default=False)
     cipher = models.CharField(max_length=88)
     salt = models.CharField(max_length=44)
+    dt_timestamp = models.DateTimeField(auto_now_add=True)
 
     class Meta:
         constraints = [models.UniqueConstraint(fields=['keyId', 'user'], name='unique_prekey')]
@@ -73,6 +77,7 @@ class EncryptingSenderKey(models.Model):
     """
     keyId = models.IntegerField()
     preKey = models.OneToOneField(PreKey, on_delete=models.CASCADE, related_name='encryptingSenderKey')
+    identityKey = models.ForeignKey(IdentityKey, on_delete=models.CASCADE, related_name='encryptingSenderKey')
     partyId = models.CharField(max_length=100)
     chainId = models.CharField(max_length=10)
     step = models.IntegerField(default=0)
@@ -102,6 +107,7 @@ class DecryptingSenderKey(models.Model):
     """
     key = models.CharField(max_length=500)
     preKey = models.OneToOneField(PreKey, on_delete=models.CASCADE, related_name='decryptingSenderKey', blank=True, null=True)
+    identityKey = models.ForeignKey(IdentityKey, on_delete=models.CASCADE, related_name='encryptingSenderKey', blank=True, null=True)
     stickId = models.CharField(max_length=100)
     partyId = models.CharField(max_length=100, blank=True, null=True)
     ofUser = models.ForeignKey(User, on_delete=models.CASCADE, related_name='decryptingSenderKeys', null=True)
